/**************************************************************************/
/*  default_theme_icons.gen.h                                             */
/**************************************************************************/
/*                         This file is part of:                          */
/*                             GODOT ENGINE                               */
/*                        https://godotengine.org                         */
/**************************************************************************/
/* Copyright (c) 2014-present Godot Engine contributors (see AUTHORS.md). */
/* Copyright (c) 2007-2014 Juan Linietsky, Ariel Manzur.                  */
/*                                                                        */
/* Permission is hereby granted, free of charge, to any person obtaining  */
/* a copy of this software and associated documentation files (the        */
/* "Software"), to deal in the Software without restriction, including    */
/* without limitation the rights to use, copy, modify, merge, publish,    */
/* distribute, sublicense, and/or sell copies of the Software, and to     */
/* permit persons to whom the Software is furnished to do so, subject to  */
/* the following conditions:                                              */
/*                                                                        */
/* The above copyright notice and this permission notice shall be         */
/* included in all copies or substantial portions of the Software.        */
/*                                                                        */
/* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,        */
/* EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF     */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. */
/* IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY   */
/* CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,   */
/* TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE      */
/* SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                 */
/**************************************************************************/

/* THIS FILE IS GENERATED. EDITS WILL BE LOST. */

#pragma once

#include "modules/modules_enabled.gen.h"

inline constexpr int default_theme_icons_count = 96;
inline constexpr const char *default_theme_icons_sources[] = {
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" d="m7 1v6h-6v2h6v6h2v-6h6v-2h-6v-6z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#b2b2b2" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".45" stroke-width="2" d="m5 7 3 3 3-3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#b2b2b2" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".45" stroke-width="2" d="m9 11-3-3 3-3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#b2b2b2" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".45" stroke-width="2" d="m6 11 3-3-3-3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#b2b2b2" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".45" stroke-width="2" d="m11.011063 9.9776246-3.0222094-2.9776246-2.9776247 3.02221"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><g fill="#fefffe" fill-opacity=".85"><path d="M14.5 1.5h-13v13L8 9.25l6.5 5.25z"/><path stroke="#fefffe" stroke-linejoin="round" stroke-opacity=".85" d="M14.5 1.5h-13v13L8 9.25l6.5 5.25z"/></g></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="7" fill="#ff5d5d" fill-opacity=".5"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><rect width="14" height="14" x="1" y="1" fill="#fff" fill-opacity=".75" rx="2.333"/><path fill="#1a1a1a" d="m11.5 3.75-5.6 5.6-1.7-1.7-1.5 1.5 3.2 3.2 7.1-7.1z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><rect width="14" height="14" x="1" y="1" fill="#fff" fill-opacity=".37" rx="2.333"/><path fill="#1a1a1a" fill-opacity=".5" d="m11.5 3.75-5.6 5.6-1.7-1.7-1.5 1.5 3.2 3.2 7.1-7.1z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#e0e0e0" d="m8 1a1 1 0 0 0 -1 1v5h-2c-1.108 0-2 .892-2 2v1h10v-1c0-1.108-.892-2-2-2h-2v-5a1 1 0 0 0 -1-1zm-5 10v4l10-1v-3z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#fff" fill-opacity=".75" d="m1 3 2-2 5 5 5-5 2 2-5 5 5 5-2 2-5-5-5 5-2-2 5-5z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#fff" d="m1 3 2-2 5 5 5-5 2 2-5 5 5 5-2 2-5-5-5 5-2-2 5-5z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 16 20"><path fill="#b2b2b2" stroke="#b2b2b2" stroke-linejoin="round" d="m3.564 15.218h8.872l-4.436-4.436z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="12" height="12"><circle cx="6" cy="6" r="5" fill="none" stroke="#fff"/><circle cx="6" cy="6" r="4" fill="none" stroke="#000"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="12" height="12"><circle cx="6" cy="6" r="4" fill="#fff"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#fff" stroke="#000003" d="m.5.5v10l10-10z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" d="M10 3a1 1 0 0 0-4 0v2H5v2h1v5c0 .712.36 1.372 1 1.73V15h2v-1.27c.618-.36 1-1 1-1.73V7h1V5h-1V3zM7 7h2v5a1 1 0 0 1-2 0z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#ff5d5d" d="M2 1v8.586l1.293-1.293a1 1 0 0 1 1.414 0L7 10.587l2.293-2.293a1 1 0 0 1 1.414 0L13 10.586l1-1V6H9V1H2zm8 0v4h4zm-6 9.414-2 2V15h12v-2.586l-.293.293a1 1 0 0 1-1.414 0L10 10.414l-2.293 2.293a1 1 0 0 1-1.414 0L4 10.414z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#e0e0e0" d="M8 1.7 5.626 5.797 1 6.895l3.236 3.408-.359 4.673 4.14-1.977 4.157 1.942-.396-4.653L15 6.895l-4.626-1.098z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" d="M2 1v14h12V6H9V1zm8 0v4h4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#e0e0e0" d="m2 2v2h2v-2zm4 0v2h8v-2zm-4 5v2h2v-2zm4 0v2h8v-2zm-4 5v2h2v-2zm4 0v2h8v-2z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#e0e0e0" d="m2 2v5h5v-5zm7 0v5h5v-5zm-7 7v5h5v-5zm7 0v5h5v-5z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="64" height="64"><path fill="#fff" fill-opacity=".6" d="M14 5a4 4 0 0 0-4 4v46a4 4 0 0 0 4 4h36a4 4 0 0 0 4-4V22a1 1 0 0 0-.29-.707l-16-16a1 1 0 0 0-.707-.29V5H14zm0 2h22v12a4 4 0 0 0 4 4h12v32a2 2 0 0 1-2 2H14a2 2 0 0 1-2-2V9a2 2 0 0 1 2-2z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" d="M2 2a1 1 0 0 0-1 1v10a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1h-4a1 1 0 0 1-1-1V3a1 1 0 0 0-1-1z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" d="M2 3a1 1 0 0 0-1 1v10a1 1 0 0 0 1 1h8v-1H8v-4h2V8h4v2h1V7a1 1 0 0 0-1-1h-4a1 1 0 0 1-1-1V4a1 1 0 0 0-1-1Z"/><path fill="#fefffe" d="M13 13h2v-2h-2V9h-2v2H9v2h2v2h2z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="64" height="64"><path fill="#e0e0e0" d="M12 10a4 4 0 0 0-4 4v36a4 4 0 0 0 4 4h40a4 4 0 0 0 4-4V22a4 4 0 0 0-4-4H36l-2-4c-1-2-2-4-4-4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#b2b2b2" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M8 11V4m4 4L8 4 4 8"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="10" height="10"><circle cx="5" cy="5" r="5" fill="#fff"/><circle cx="5" cy="5" r="3.667" fill="#b2b2b2" fill-opacity=".65"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><g fill="none" stroke-width="1.3"><path stroke="#fefffe" stroke-linejoin="round" d="M1.87 6.541h2.917v2.917H1.87zm4.666 0h2.917v2.917H6.536zm4.666 0h2.917v2.917h-2.917z"/><path stroke="#e0e0e0" stroke-linecap="round" stroke-opacity=".65" d="m5.432 1.112-1.95 1.95 1.95 1.95m-1.95-1.95h9.386m-2.137 8.05 1.95 1.95-1.95 1.95m-7.437-1.95h9.387"/></g></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" stroke-linejoin="round" stroke-miterlimit="2"><path fill="#b2b2b2" fill-opacity=".65" d="M14 2.199v2.615l-2.625 1.313V3.512zM2 6.264l2.625 1.312v2.551L2 8.814zm12 0v2.55l-2.625 1.313V7.576zM6 7.719h4v2.64H6zm-4 2.56 2.625 1.313v2.521L2 12.801zm12 0v2.522l-2.625 1.312v-2.521zm-8 1.455h4v2.641H6zm4-8.109v2.734H5.844s-.749.647-.875.641c-.131-.007-1.51-1.456-1.51-1.456L2 4.814V2.199l.117.06s-.064-.775.424-1.216L1.279.441A.626.626 0 0 0 .375 1v12c0 .237.134.453.346.559l4 2a.626.626 0 0 0 .279.066h6a.626.626 0 0 0 .279-.066l4-2a.625.625 0 0 0 .346-.559V1a.625.625 0 0 0-.904-.559l-3.869 1.934H7.888s.084.624-.218 1.25z"/><path fill="#fefffe" d="M5 6.25c-4-3.5-2-6 0-6s4 2.5 0 6z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" fill-opacity=".65" d="M3 0v3H0v2h3v4H0v2h3v3h2V5h9V3h-3V0H9v3H5V0zm4 13v2h2v-2zm6 0v2h2v-2z"/><path fill="#fefffe" d="M7 11v2h2v-2a2 2 0 0 1 4 0v2h2v-2a4 4 0 0 0-8 0z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" fill-opacity=".65" d="M3 0v3H0v2h3v4H0v2h3v3h2V5h9V3h-3V0H9v3H5V0z"/><path fill="#e0e0e0" d="M11 6.62c-1.747 0-3.957 1.344-4.752 3.936a.683.69 0 00-.004.394C7.012 13.665 9.292 14.9 11 14.9c1.708 0 3.988-1.235 4.756-3.95a.683.69 0 000-.382C15.004 7.955 12.746 6.62 11 6.62zM11 8a2.733 2.76 0 012.733 2.76A2.733 2.76 0 0111 13.52a2.733 2.76 0 01-2.733-2.76A2.733 2.76 0 0111 8zm0 1.38a1.367 1.38 0 00-1.367 1.38A1.367 1.38 0 0011 12.14a1.367 1.38 0 001.367-1.38A1.367 1.38 0 0011 9.38z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="30" height="60"><rect width="28" height="58" x="1" y="1" fill="#e0e0e0" fill-opacity=".6" stroke="#000" stroke-width=".8" rx="7"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="4" height="8"><path fill="#fff" fill-opacity=".25" d="M1 0h2v16H1z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="8" height="48"><path fill="gray" fill-opacity=".65" d="M3.15 4v40h1.7V4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><rect width="14" height="14" x="1" y="1" fill="#fff" fill-opacity=".75" rx="2.333"/><path fill="#1a1a1a" d="m3 7h10v2h-10z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><rect width="14" height="14" x="1" y="1" fill="#fff" fill-opacity=".37" rx="2.333"/><path fill="#1a1a1a" fill-opacity=".5" d="m3 7h10v2h-10z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#fff" fill-opacity=".75" d="m1 3 2-2 5 5 5-5 2 2-5 5 5 5-2 2-5-5-5 5-2-2 5-5z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#e0e0e0" d="M3 2a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2h9c1.105 0 1.818-.91 2-2l1-6a1 1 0 0 0-1-1H6c-.552 0-.909.455-1 1l-1 6c-.091.545-.448 1-1 1a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1 1 1 0 0 0 1 1h5a1 1 0 0 0-1-1H7a2 2 0 0 0-2-2H3z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="gray" d="M0 0v8h8V0zm8 8v8h8V8z"/><path fill="#fff" d="M8 0v8h8V0zm0 8H0v8h8z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#e0e0e0" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M10 2H6m2 4v8M4 9l4 5 4-5"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#e0e0e0" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M6 14h4m-2-4V2m4 5L8 2 4 7"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="12" height="12"><path fill="none" stroke="#b2b2b2" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".85" stroke-width="2" d="m2 4 4 4 4-4"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#eaeaea" d="M6.5 2.5a5.5 5.5 0 0 0 0 11 5.5 5.5 0 0 0 0-11m6.5 0h2v11h-2z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#eaeaea" d="M.5 2.5h11v11H.5zm12 0h2v11h-2z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="5.25" fill="none" stroke="#eaeaea" stroke-width="1.75"/><path fill="#eaeaea" d="M4.9 4.9h6.2v6.2H4.9z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="8" height="16"><path fill="none" stroke="#b2b2b2" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".45" stroke-width="2" d="m5.5 11-3-3 3-3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="8" height="16"><path fill="none" stroke="#b2b2b2" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".45" stroke-width="2" d="m2.5 11 3-3-3-3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="5.5" fill="#1a1a1a" stroke="#fff" stroke-opacity=".75" stroke-width="3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="7" fill="#fff" fill-opacity=".37"/><circle cx="8" cy="8" r="4" fill="#1a1a1a" fill-opacity=".5"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="7" fill="#1a1a1a" fill-opacity=".5"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="7" fill="#1a1a1a" fill-opacity=".25"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="12" height="12"><path fill="#fff" d="M3 2a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1V3a1 1 0 0 0-1-1zm2.75 7a1 1 0 0 1-1.414-1.414L5.922 6 4.336 4.414A1 1 0 0 1 5.75 3l2.293 2.293a1 1 0 0 1 0 1.414z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="12" height="12"><path fill="#fff" d="M10 3a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h6a1 1 0 0 0 1-1zM3 5.75a1 1 0 0 1 1.414-1.414L6 5.922l1.586-1.586A1 1 0 0 1 9 5.75L6.707 8.043a1 1 0 0 1-1.414 0z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" d="M5 8a4 4 0 1 1 4 4v2a6 6 0 1 0-6-6H1l3 4 3-4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#fefffe" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".65" stroke-width="2" d="M4 11V4h7"/><circle cx="7.5" cy="7.5" r="1.5" fill="#b2b2b2" fill-opacity=".65"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#fefffe" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".65" stroke-width="2" d="M11 4v7H4"/><circle cx="7.5" cy="7.5" r="1.5" fill="#b2b2b2" fill-opacity=".65"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#e0e0e0" d="M3 1a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V4l-3-3h-1v6H3zm1 0v5h3V1zm4 8a1 1 0 0 1 0 4 1 1 0 0 1 0-4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#e0e0e0" d="M6 1a2 2 0 0 0-2 2v7H1v3a2 2 0 0 0 2 2h7a2 2 0 0 0 2-2V5h3V3a2 2 0 0 0-2-2z"/><path fill-opacity=".2" d="M6 1a2 2 0 0 0-2 2v7H1v3a2 2 0 1 0 4 0V3a1 1 0 0 1 2 0v3h5V5H8V3a2 2 0 0 0-2-2zM2 11h2v2a1 1 0 0 1-2 0z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="6" fill="#fefffe" fill-opacity=".75"/><path fill="none" stroke="#1a1a1a" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".65" stroke-width="2" d="m9 5-3 3 3 3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="6" fill="#fefffe"/><path fill="none" stroke="#1a1a1a" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="m9 5-3 3 3 3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="6" fill="#fefffe" fill-opacity=".75"/><path fill="none" stroke="#1a1a1a" stroke-linecap="round" stroke-linejoin="round" stroke-opacity=".65" stroke-width="2" d="m7 5 3 3-3 3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="6" fill="#fefffe"/><path fill="none" stroke="#1a1a1a" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="m7 5 3 3-3 3"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="24" height="32" viewBox="0 0 6.35 8.467"><defs><linearGradient id="a"><stop offset="0" stop-color="#fff" stop-opacity=".3"/><stop offset="1" stop-color="#fff" stop-opacity="0"/></linearGradient><linearGradient xlink:href="#a" id="b" x1="4.233" x2="4.233" y1="0" y2="6.35" gradientTransform="translate(-8.467)" gradientUnits="userSpaceOnUse"/></defs><path fill="url(#b)" d="M-8.467 0H0V6.35H-8.467z" paint-order="fill markers stroke" transform="rotate(-90)"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="32" height="24" viewBox="0 0 8.467 6.35"><defs><linearGradient id="a"><stop offset="0" stop-color="#fff" stop-opacity=".3"/><stop offset="1" stop-color="#fff" stop-opacity="0"/></linearGradient><linearGradient xlink:href="#a" id="b" x1="4.233" x2="4.233" y1="0" y2="6.35" gradientUnits="userSpaceOnUse"/></defs><path fill="url(#b)" d="M0 0H8.467V6.35H0z" paint-order="fill markers stroke"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="7" fill="#fefefe" fill-opacity=".75"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="7" fill="#fefefe" fill-opacity=".37"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="7" fill="#fefefe"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#e0e0e0" d="M9 1v2h6V1zM4 1a1 1 0 0 0-.691.291l-2 2a1 1 0 0 0 1.414 1.414l.293-.293v7.172l-.293-.293a1 1 0 0 0-1.414 1.414l2 2a1 1 0 0 0 1.414 0l2-2a1 1 0 0 0-1.414-1.414l-.293.293V4.412l.293.293a1 1 0 0 0 1.414-1.414l-2-2A1 1 0 0 0 4 1zm5 6v2h4V7zm0 6v2h2v-2z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="32"><path fill="#d3d3d3" d="m5 1h6v30h-6z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" fill-opacity=".45" d="M8 0a2 2 0 0 0 0 4 2 2 0 0 0 0-4zm0 6a2 2 0 0 0 0 4 2 2 0 0 0 0-4zm0 6a2 2 0 0 0 0 4 2 2 0 0 0 0-4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" fill-opacity=".65" d="M8 0a2 2 0 0 0 0 4 2 2 0 0 0 0-4zm0 6a2 2 0 0 0 0 4 2 2 0 0 0 0-4zm0 6a2 2 0 0 0 0 4 2 2 0 0 0 0-4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="14" height="8"><path fill="#fefffe" fill-opacity=".25" d="M4 0a4 4 0 0 0 0 8h6a4 4 0 0 0 0-8zM3 3a1 1 0 0 1 0 2 1 1 0 0 1 0-2zm4 0a1 1 0 0 1 0 2 1 1 0 0 1 0-2zm4 0a1 1 0 0 1 0 2 1 1 0 0 1 0-2z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="8" height="8"><circle cx="4" cy="4" r="1.5" fill="#b2b2b2" fill-opacity=".25"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="8" height="8"><path fill="#b2b2b2" fill-opacity=".25" d="M6 0v8h2V0zM1 0a1 1 0 0 0-.693 1.705L2.6 3.998.307 6.291A1 1 0 0 0 1.72 7.705l3-3a1 1 0 0 0 0-1.414l-3-3A1 1 0 0 0 1 0z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><g fill="#e0e0e0"><path d="m13.297.714h-13.013a.454.454 0 0 0 -.318.779l4.615 4.507v7.086a.45.45 0 0 0 .738.354l3.511-2.812a.454.454 0 0 0 .17-.354v-4.274l4.614-4.506a.454.454 0 0 0 -.317-.779z"/><path d="m11.085832 14.18196c3.399443 1.97457 6.855925-2.441094 4.074102-5.1815164-2.781825-2.7404217-7.2642008.6646174-5.2597994 4.0134654l-1.9001346 1.871854 1.1856973 1.168051zm1.699723-4.4945981c2.236109 0 2.236109 3.3042441 0 3.3042441-2.236108 0-2.236108-3.3042441 0-3.3042441z"/></g></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="32" height="16"><g fill-opacity=".5"><rect width="30" height="14" x="1" y="1" fill="#1a1a1a" rx="7"/><circle cx="8" cy="8" r="5" fill="#fff"/></g></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="32" height="16"><g fill-opacity=".25"><rect width="30" height="14" x="1" y="1" fill="#1a1a1a" rx="7"/><circle cx="8" cy="8" r="5" fill="#fff"/></g></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="32" height="16"><g fill-opacity=".25"><rect width="30" height="14" x="1" y="1" fill="#1a1a1a" rx="7"/><circle cx="24" cy="8" r="5" fill="#fff"/></g></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="32" height="16"><g fill-opacity=".5"><rect width="30" height="14" x="1" y="1" fill="#1a1a1a" rx="7"/><circle cx="24" cy="8" r="5" fill="#fff"/></g></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="32" height="16"><rect width="30" height="14" x="1" y="1" fill="#fff" fill-opacity=".75" rx="7"/><circle cx="24" cy="8" r="5" fill="#1a1a1a"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="32" height="16"><rect width="30" height="14" x="1" y="1" fill="#fff" fill-opacity=".37" rx="7"/><circle cx="24" cy="8" r="5" fill="#1a1a1a" fill-opacity=".5"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="32" height="16"><rect width="30" height="14" x="1" y="1" fill="#fff" fill-opacity=".37" rx="7"/><circle cx="8" cy="8" r="5" fill="#1a1a1a" fill-opacity=".5"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="32" height="16"><rect width="30" height="14" x="1" y="1" fill="#fff" fill-opacity=".75" rx="7"/><circle cx="8" cy="8" r="5" fill="#1a1a1a"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><rect width="14" height="14" x="1" y="1" fill="#1a1a1a" fill-opacity=".5" rx="2.333"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><rect width="14" height="14" x="1" y="1" fill="#1a1a1a" fill-opacity=".25" rx="2.333"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="none" stroke="#fff" stroke-opacity=".75" stroke-width="2" d="m4 6 4-3.5L12 6m0 4-4 3.5L4 10"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="60" height="30"><rect width="58" height="28" x="1" y="1" fill="#e0e0e0" fill-opacity=".6" stroke="#000" stroke-width=".8" rx="7"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="8"><path fill="none" stroke="#fff" stroke-width="2" d="m12 2-4 3.5L4 2"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="8"><path fill="none" stroke="#fff" stroke-width="2" d="m4 6 4-3.5L12 6"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><path fill="#b2b2b2" d="M8 2C5.443 2 2.209 3.948 1.045 7.705a1 1 0 0 0 0 .55C2.163 12.211 5.5 14 8 14s5.836-1.789 6.961-5.725a1 1 0 0 0 0-.55C13.861 3.935 10.554 2 8 2zm0 2a4 4 0 0 1 0 8 4 4 0 0 1 0-8zm0 2a2 2 0 0 0 0 4 2 2 0 0 0 0-4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="8" height="4"><path fill="#fff" fill-opacity=".25" d="M0 3V1h16v2z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="48" height="8"><path fill="none" stroke="gray" stroke-opacity=".65" stroke-width="1.7" d="M4 4h40"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="8" fill="#b2b2b2" fill-opacity=".65"/><circle cx="8" cy="8" r="7" fill="#fefffe"/><path fill="#010001" d="M4 7h8v2H4z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="8" fill="#b2b2b2" fill-opacity=".65"/><circle cx="8" cy="8" r="7" fill="#fefffe"/><path fill="#010001" d="M7 4h2v3h3v2H9v3H7V9H4V7h3z"/></svg>
)<!>",
	R"<!>(<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16"><circle cx="8" cy="8" r="8" fill="#b2b2b2" fill-opacity=".65"/><circle cx="8" cy="8" r="7" fill="#fefffe"/><path fill="#010001" d="M8 4.166A1 1 0 0 1 9.526 5v7h-2V6.87l-1.445.962-1-1.6z"/></svg>
)<!>"
};

inline constexpr const char *default_theme_icons_names[] = {
	"add",
	"arrow_down",
	"arrow_left",
	"arrow_right",
	"arrow_up",
	"bookmark",
	"breakpoint",
	"checked",
	"checked_disabled",
	"clear",
	"close",
	"close_hl",
	"color_picker_bar_arrow",
	"color_picker_cursor",
	"color_picker_cursor_bg",
	"color_picker_overbright",
	"color_picker_pipette",
	"error_icon",
	"favorite",
	"file",
	"file_mode_list",
	"file_mode_thumbnail",
	"file_thumbnail",
	"folder",
	"folder_create",
	"folder_thumbnail",
	"folder_up",
	"graph_port",
	"grid_layout",
	"grid_minimap",
	"grid_snap",
	"grid_toggle",
	"h_dragger",
	"hslider_tick",
	"hsplitter",
	"indeterminate",
	"indeterminate_disabled",
	"line_edit_clear",
	"load",
	"mini_checkerboard",
	"move_down",
	"move_up",
	"option_button_arrow",
	"picker_shape_circle",
	"picker_shape_rectangle",
	"picker_shape_rectangle_wheel",
	"popup_menu_arrow_left",
	"popup_menu_arrow_right",
	"radio_checked",
	"radio_checked_disabled",
	"radio_unchecked",
	"radio_unchecked_disabled",
	"region_folded",
	"region_unfolded",
	"reload",
	"resizer_nw",
	"resizer_se",
	"save",
	"script",
	"scroll_button_left",
	"scroll_button_left_hl",
	"scroll_button_right",
	"scroll_button_right_hl",
	"scroll_hint_horizontal",
	"scroll_hint_vertical",
	"slider_grabber",
	"slider_grabber_disabled",
	"slider_grabber_hl",
	"sort",
	"tabs_drop_mark",
	"tabs_menu",
	"tabs_menu_hl",
	"text_edit_ellipsis",
	"text_edit_space",
	"text_edit_tab",
	"toggle_filename_filter",
	"toggle_off",
	"toggle_off_disabled",
	"toggle_off_disabled_mirrored",
	"toggle_off_mirrored",
	"toggle_on",
	"toggle_on_disabled",
	"toggle_on_disabled_mirrored",
	"toggle_on_mirrored",
	"unchecked",
	"unchecked_disabled",
	"updown",
	"v_dragger",
	"value_down",
	"value_up",
	"visibility_visible",
	"vslider_tick",
	"vsplitter",
	"zoom_less",
	"zoom_more",
	"zoom_reset"
};
